/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import logger from '../../../middleware/logger';
import {Guid} from 'guid-typescript';

/**
 * Router Definition
 */
export const generalInfoRouter = express.Router();

generalInfoRouter.get('/', async (req: Request, res: Response) => {
	try {
		res.status(200).send('GET generalInfo v2.1');
	} catch (e: any) {
		let errorGuid = Guid.create().toString();
		logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
		res.status(500).send({
			'status': 'PROCESSING_ERROR',
			'message': 'Internal Server Error. Try again later.',
			'reference': errorGuid
		});
	}
});

generalInfoRouter.post('/', async (req: Request, res: Response) => {
	try {
		res.status(200).send('POST generalInfo v2.1');
	} catch (e: any) {
		let errorGuid = Guid.create().toString();
		logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
		res.status(500).send({
			'status': 'PROCESSING_ERROR',
			'message': 'Internal Server Error. Try again later.',
			'reference': errorGuid
		});
	}
});
